@@ -3,6 +3,7 @@ from urllib.parse import urlencode
 
 from django.urls import reverse_lazy
 from django.contrib import admin
+from django.contrib import messages
 from django.shortcuts import render, redirect
 from django.utils.translation import ugettext_lazy as _
 
@@ -28,10 +29,15 @@ def generate_codes(request):
     context = admin.site.each_context(request)
 
     if request.method == 'POST':
-        count = int(request.POST['count'])
-        codes = BarCode.get_solo().get_next_codes(count)
-        url = reverse_lazy('barcode:print')
-        url += '?' + urlencode({'codes': ','.join(map(str, codes))})
+        try:
+            count = int(request.POST['count'])
+            codes = BarCode.get_solo().get_next_codes(count)
+            url = reverse_lazy('barcode:print')
+            url += '?' + urlencode({'codes': ','.join(map(str, codes))})
+        except Exception:
+            messages.error(request, _('Incorrect number'))
+            url = request.path
+
         return redirect(url)
 
     return render(request, 'barcode/generate.html', context)
