@@ -46,3 +46,24 @@ class BarCode(SingletonModel):
     class Meta:
         verbose_name = _('Bar code')
         verbose_name_plural = _('Bar codes')
+
+
+class BarCodeField(models.CharField):
+
+    def __init__(
+            self,
+            verbose_name=_('Bar code'),
+            null=True,
+            blank=True,
+            max_length=255,
+            db_index=True,
+            **kwargs):
+        super().__init__(
+            verbose_name=verbose_name,
+            null=null,
+            blank=blank,
+            max_length=max_length,
+            db_index=db_index,
+            **kwargs
+        )
+
